;; Elephant Poaching ABM ;;

breed [ elephants elephant ]
breed [ herds herd ]
breed [ poachers poacher ]
breed [ vision-cones vision-cone ]
breed [ villages village ]

globals [
  death-poaching
  death-age
  caught-by-poacher
  matriarchs
]

turtles-own [
  nearest-poacher
  nearest-elephant
]

breed [zones zone]

zones-own [
  my-patches
  num-times-visited-by-poachers
  num-times-poachers-caught
  probability-of-catching-poacher
]

undirected-link-breed [ zone-links zone-link ]

zone-links-own [
  num-elephants-seen
  num-times-visited
]

elephants-own [
  gender
  age
  max-age
  status
  my-herd-number
  herdmates
  nearest-neighbor
  elephant-vision
]

poachers-own [
  number-catches
  lifetime-catches
  count-down
  number-of-trips
]

patches-own [
  countdown
  food-source-number
  food
  zone-here
]

to setup
  clear-all
  resize-world -20 20 -20 20                         ;; resize world so the grid fits evenly in it
                                                     ; set-up food/bare patches
  ask patches [
    set pcolor one-of [64 62]
  ]

  ;; create village ;;;
  ask patch -10 15 [
    sprout-villages 1 [
      set color yellow
      set shape "house"
      set size 2
    ]
  ]

  setup-patches
  setup-zones
  setup-elephants
  setup-poachers
  setup-migration

  reset-ticks
end


to setup-patches

  ask patches [
  ]

  ; to draw grid

  ;; draw x-axis & y-axis as light gray
  ask patches with [pxcor = 0 or pycor = 0]
  [ set pcolor gray - 3]
  ; ask patches with [pxcor = 10 or pycor = 10]
  ;   [ set pcolor gray - 3]
  ; ask patches with [pxcor = -10 or pycor = -10]
  ;   [ set pcolor gray - 3]
  ask patches with [pxcor = 20 or pycor = 20]
  [ set pcolor gray - 3]
  ask patches with [pxcor = -20 or pycor = -20]
  [ set pcolor gray - 3]


end

to setup-migration
  ask patches [
  ;; setup food source one on the right
  if (distancexy (0.6 * max-pxcor) 0) < 5
  [ set food-source-number 1]
  ;; setup food source two on the lower-left
  if (distancexy (-0.6 * max-pxcor) (-0.6 * max-pycor)) < 5
  [ set food-source-number 2 ]
  ;; setup food source three on the upper-left
  if (distancexy (-0.8 * max-pxcor) (0.8 * max-pycor)) < 5
  [ set food-source-number 3 ]
  if (distancexy (-0.3 * max-pxcor) (0.3 * max-pycor)) < 5
  [ set food-source-number 4 ]
  if (distancexy (-0.9 * max-pxcor) (0.4 * max-pycor)) < 5
  [ set food-source-number 5 ]
  ]
end


to setup-zones ;; draw zones

  create-zones 4
  let sorted-zones sort zones

  ask item 0 sorted-zones [
    set my-patches patches with [pxcor >= 0 and pycor >= -20 and pycor <= 0]
  ]

  ask item 1 sorted-zones [
    set my-patches patches with [pxcor >= 0 and pycor >= 0]
  ]

  ask item 2 sorted-zones [
    set my-patches patches with [pxcor >= -20 and pxcor <= 0 and pycor >= -20 and pycor <= 0]
  ]

  ask item 3 sorted-zones [
    set my-patches patches with [pxcor >= -20 and pxcor <= 0 and pycor >= 0]
  ]

  ask zones [
    hide-turtle
    ask my-patches [ set zone-here myself ]
  ]

end

to setup-elephants
  create-elephants initial-number-elephants [
    set max-age 60
    set my-herd-number (random number-of-herds) + 1
    set elephant-vision 1
    set gender "male"                                               ;; elephants are either male or female
    set color black
    set shape "mammoth"
    set size 1
    setxy random-xcor random-ycor
    if random 2 = 1
    [ set gender "female"
      set color white
    ]

    set status "follower"                                           ;; status of elephants are either "follower" or "matriarch"
    set age random max-age
  ]

  setup-matriarchs

  ask elephants with [status != "matriarch" ] [
    let my-matriarch one-of elephants with [status = "matriarch" and my-herd-number = [ my-herd-number ] of myself ]
    move-to my-matriarch
    forward random-float elephant-vision
  ]
end

to setup-matriarchs
  ;;prepare a list where we hold all the matriarchs
  set matriarchs []

  ; go through each herd, by index
  let index 1
  loop [
    ;;pick one elephant at random
    let new_matriarch one-of (elephants with [ my-herd-number = index]) with-max [age]
    ;;ask the matriarch to change color
    ask new_matriarch
    [
      ;;change its color, age, status
      set color red
      set status "matriarch"
      set gender "female"
    ]

    ;;add it to the list of matriarchs
    set matriarchs lput new_matriarch matriarchs
    ;; go to next herd
    set index (index + 1)
    ;; if you run out of herds, stop
    if index > number-of-herds
    [stop]
  ]
end

to setup-poachers
  set-default-shape poachers "person"
  create-poachers initial-number-poacher ; create the people
  [
    set color 45
    set size 1
    move-to one-of villages            ;; set their location as the village
 ;; can raise or lower this depending on equipment / technology (i.e. on-foot vs. helicopters)
    set count-down random 10
    set number-of-trips 0
    create-zone-links-with zones [hide-link]
  ]
end

to-report random-in-range [low high]
  report low + random (high - low + 1)
end

to go
if not any? poachers [ stop ]
if not any? elephants [ stop ]
if ticks = 365 [stop]

  ask elephants [
    move-matriarch
    death
    if ticks mod 365 = 0
    [
      set age age + 1
      reproduce-elephant
    ]
  ]

  ask poachers
  [
    set count-down count-down - 1
    if count-down = 0 and in-village?
    [
      start-poaching-trip
      if poacher-movement = "random" [  move-randomly ]
      if poacher-movement = "adaptive" [ adaptive-poacher]
      catch-elephants
      die-poacher
    ]

    if count-down = 0 and in-village? = FALSE
      [
        move-to one-of villages
        set count-down 5 + random 5
      ]
  ]


    if law-enforcement-strategy = "follow herds" [ follow-elephants ]
    if law-enforcement-strategy = "follow schedule" [ follow-schedule ]


    tick
end


to move-matriarch
  if not any? turtles [stop]

  ;season movement for the matriarch, herd follows

  ifelse status = "matriarch"
    [
      let day-of-the-year ticks mod 365
      let special_number ( my-herd-number mod 5 ) + 1
      ; print special_number
      ifelse (day-of-the-year > 180) [
        face one-of patches with [ food-source-number = special_number]
      ][
        ifelse (day-of-the-year > 90) [
          face one-of patches with [ food-source-number = (special_number + 1) mod 5 + 1]
        ]
        [
          face one-of patches with [food-source-number = (special_number + 2) mod 5 + 1]
        ]
      ]
    ]

  [
    move-herd
  ]
  fd 1
end

to move-herd
  ;grab my matriarch
  if gender = "female" or (gender = "male" and age < 15) [
    let my-matriarch one-of elephants with [status = "matriarch" and my-herd-number = [ my-herd-number ] of myself ]
    ifelse my-matriarch != nobody [
      move-to my-matriarch
      forward random-float elephant-vision
    ]
    [

      if gender = "male" and age >= 14 [

        rt random 20 - 10

      ]
      fd 1
    ]
  ]
end

to reproduce-elephant
  ; give birth in every 6 years after certain age
  if gender = "female" and age >= 13 and age mod 5 = 0
    [

      ;; some default values
      let offspring-gender "male"
      let offspring-color black

      if random 2 = 1      ;; initial gender distribution is 50%
        [
          set offspring-gender "female"
          set offspring-color white
      ]

      ;; hello world
      hatch 1 [
        set age 1
        move-to one-of patches with [not shade-of? blue pcolor]
        set gender offspring-gender
        set color offspring-color
        set status "follower"
      ]
  ]
  if count elephants with [ gender = "male" ] = 0 or count elephants with [ gender = "female" ] = 0 [ stop ]

end


to death  ; turtle procedure
          ; with random probability and/or max age, die
  let going_to_die false

  if age > max-age and not going_to_die
    [
      set death-age death-age + 1
      set going_to_die true
  ]


  if going_to_die = true
    [
      ifelse status = "matriarch"
      [death-matriarch]
      [die]
  ]

end

to death-matriarch
  let this-herd my-herd-number
  ;;pick one elephant at random
  if elephants with [status = "matriarch"] != nobody [
    let new_matriarch  one-of (elephants with [ my-herd-number = this-herd and gender = "female" and status = "follower"]) with-max [age]
    ;;ask the matriarch to change color
    if new_matriarch != nobody [
      ask new_matriarch
      [
        ;;change its color, age, status
        set color red
        set status "matriarch"
      ]
    ]

    ;;add it to the list of matriarchs
    ;   print(matriarchs)
    set matriarchs replace-item (this-herd - 1) matriarchs new_matriarch
    ;    print(matriarchs)

    die
  ]

  if elephants with [status = "matriarch"] = nobody [stop]
end


to start-poaching-trip
  set number-of-trips number-of-trips + 1
  set count-down 3
  set count-down count-down - 1
end

to die-poacher
  ; people procedure
  let p [ probability-of-catching-poacher ] of zone-here
    if(random-float 1 < p) [
      ask zone-here [set num-times-poachers-caught num-times-poachers-caught + 1 ]
      die
    ]
end

to move-randomly
  ;poacher moves randomly
 visit-zone one-of zones
end

to visit-zone [ target-zone ]
  move-to [ one-of my-patches ] of target-zone
  ask zone-link-with target-zone [ set num-times-visited num-times-visited + 1
  ]
  ask zone-here [ set num-times-visited-by-poachers num-times-visited-by-poachers + 1]

end


to follow-schedule
  let day-of-the-week ticks mod 7

  ;;;; if the ranger schedule occurs on a set number of days (once a week)

ifelse day-of-the-week = 3 [
  (foreach (sort zones) [0.15 0.25 0.1 0] [ [the-zone the-probability] ->
    ask the-zone [ set probability-of-catching-poacher the-probability ]
  ])
] [
  ask zones [ set probability-of-catching-poacher 0 ]
]

end

to adaptive-poacher

 let destination-zone
   [other-end] of one-of my-zone-links with-max [
     (num-elephants-seen / (num-times-visited + 1)) -
     ([num-times-poachers-caught / (num-times-visited-by-poachers + 1) ] of other-end)
   ]

visit-zone ifelse-value (number-of-trips <= 5 or random 100 < exploration-prob) [
   one-of zones
 ] [
   destination-zone
 ]

; print destination-zone
end

to follow-elephants
    ; count the number of matriarchs in each zone
    ; make ranger effort = number of matriarchs in that box divided by the total number of matriarchs
    ; when there are no matriarchs anywhere, put all effort to zero
    ; rangers are essentially following their migration routes

  let day-of-the-week ticks mod 7
  let total count elephants with [status = "matriarch" ]
  ifelse day-of-the-week = 3  and total > 0[
    ask zones [
      let matriarchs-here sum [ count elephants-here with [status = "matriarch"] ] of my-patches
      set probability-of-catching-poacher ((matriarchs-here / total) / 2)
    ]
  ] [
    ask zones [ set probability-of-catching-poacher 0 ]
  ]
end

to-report in-village? ; turtle reporter
  report any? villages-here
end

to catch-elephants

  ; Catching elephants

  let prey one-of elephants-here
  if prey != nobody [
    ask zone-link-with zone-here [ set num-elephants-seen num-elephants-seen + 1 ]

    if random-float 1 < poacher-goodness
    [
      set caught-by-poacher caught-by-poacher + 1
      set number-catches number-catches + 1
      set lifetime-catches lifetime-catches + 1
    ]


  ask prey
  [
    ifelse status = "follower" [die]
      [
        if status = "matriarch"
        [
          death-matriarch
        ]
      ]
  ]
]


end


    ;;; for plotting ;;;


to-report mean-age-females
  ifelse count elephants with [ gender = "female" ] > 0 [
    report mean [ age ] of elephants with [ gender = "female" ]
  ]
  [ report 0 ]
end


to-report mean-age-males
  ifelse count elephants with [ gender = "male" ] > 0 [
    report mean [ age ] of elephants with [ gender = "male" ]
  ]
  [ report 0 ]
end

to-report count-females
  ifelse count elephants with [ gender = "female" ] > 0 [
    report count elephants with [ gender = "female" ]
  ]
  [ report 0 ]
end

to-report count-males
  ifelse count elephants with [ gender = "male" ] > 0 [
    report count elephants with [ gender = "male" ]
  ]
  [ report 0 ]
end
@#$#@#$#@
GRAPHICS-WINDOW
448
19
989
561
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-20
20
-20
20
0
0
1
ticks
30.0

BUTTON
12
17
79
51
NIL
setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
87
17
151
51
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
13
68
223
101
initial-number-elephants
initial-number-elephants
0
400
150.0
1
1
NIL
HORIZONTAL

SLIDER
230
68
437
101
initial-number-poacher
initial-number-poacher
0
50
15.0
1
1
NIL
HORIZONTAL

SLIDER
14
107
187
140
number-of-herds
number-of-herds
0
15
10.0
1
1
NIL
HORIZONTAL

BUTTON
163
18
227
52
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1019
124
1219
274
male vs female elephants
time
number of individuals
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" "plot count-males"
"pen-1" 1.0 0 -13840069 true "" "plot count-females"

SLIDER
232
106
405
139
exploration-prob
exploration-prob
0
100
10.0
1
1
%
HORIZONTAL

SLIDER
230
143
415
176
poacher-goodness
poacher-goodness
0
100
50.0
1
1
%
HORIZONTAL

CHOOSER
12
219
160
264
poacher-movement
poacher-movement
"random" "adaptive"
1

CHOOSER
14
170
202
215
law-enforcement-strategy
law-enforcement-strategy
"follow herds" "follow schedule"
0

PLOT
1022
282
1222
432
Poachers caught by zone
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"(foreach (sort zones) (sublist base-colors 0 (count zones)) [ [ z c ] ->\ncreate-temporary-plot-pen (word z) \nset-plot-pen-color c\n]\n)" "ask zones [\nset-current-plot-pen (word self)\nplot num-times-poachers-caught\n]\n"
PENS

MONITOR
1025
440
1135
485
NIL
count poachers
17
1
11

PLOT
1228
124
1428
274
plot 1
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -13840069 true "" "plot mean-age-females"
"pen-1" 1.0 0 -5298144 true "" "plot mean-age-males"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

mammoth
false
0
Polygon -7500403 true true 195 181 180 196 165 196 166 178 151 148 151 163 136 178 61 178 45 196 30 196 16 178 16 163 1 133 16 103 46 88 106 73 166 58 196 28 226 28 255 78 271 193 256 193 241 118 226 118 211 133
Rectangle -7500403 true true 165 195 180 225
Rectangle -7500403 true true 30 195 45 225
Rectangle -16777216 true false 165 225 180 240
Rectangle -16777216 true false 30 225 45 240
Line -16777216 false 255 90 240 90
Polygon -7500403 true true 0 165 0 135 15 135 0 165
Polygon -1 true false 224 122 234 129 242 135 260 138 272 135 287 123 289 108 283 89 276 80 267 73 276 96 277 109 269 122 254 127 240 119 229 111 225 100 214 112

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="394" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="365"/>
    <metric>mean [ age ] of elephants with [ gender = "male" ]</metric>
    <enumeratedValueSet variable="initial-number-elephants">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploration-prob">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="poacher-movement">
      <value value="&quot;adaptive&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="poacher-goodness">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-number-poacher">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-herds">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="law-enforcement-strategy">
      <value value="&quot;follow herds&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
